# Image Attendant

author: Pierre V. Villeneuve

## Overview

A collection of image-processing functions that I use in many of my projects.

## Installation

To install use pip:

    $ pip install image_attendant


Or clone the repo:

    $ git clone https://github.com/who8mylunch/image_attendant.git
    $ python setup.py install

## Example

TBD
